@@ -8,7 +8,7 @@ Rubric::Entry::Query - construct and execute a complex query
 
 version 0.04
 
- $Id: Query.pm,v 1.6 2005/03/31 01:02:53 rjbs Exp $
+ $Id: Query.pm,v 1.9 2005/04/08 01:53:18 rjbs Exp $
 
 =cut
 
@@ -101,9 +101,14 @@ sub constraint_for_user {
 
 =head3 constraint_for_tags(\@tags)
 
+=head3 constraint_for_exact_tags(\@tags)
+
 Given an arrayref of tag names, this returns SQL to limit results to entries
 marked with the given tags.
 
+The C<exact> version of this constraint returns SQL for entries with only the
+given tags.
+
 =cut
 
 sub constraint_for_tags {
@@ -118,6 +123,17 @@ sub constraint_for_tags {
 		@$tags;
 }
 
+sub constraint_for_exact_tags {
+	my ($self, $tags) = @_;
+
+	return undef unless $tags and ref $tags eq 'ARRAY';
+	return unless my $count = @$tags;
+
+	return
+		"(SELECT COUNT(tag) FROM entrytags WHERE entry = entries.id) = $count",
+		$self->constraint_for_tags($tags);
+}
+
 =head3 constraint_for_has_body($bool)
 
 This returns SQL to limit the results to entries with bodies.
@@ -140,6 +156,20 @@ sub constraint_for_has_link {
 	return $bool ? "link IS NOT NULL" : "link IS NULL";
 }
 
+=head3 constraint_for_first_only($bool)
+
+This returns SQL to limit the results to the first entry posted for any given
+link.
+
+=cut
+
+sub constraint_for_first_only {
+	my ($self, $bool) = @_;
+	return $bool
+		? "(link is NULL OR id IN (SELECT MIN(id) FROM entries GROUP BY link))"
+		: ();
+}
+
 =head3 constraint_for_urimd5($md5)
 
 This returns SQL to limit the results to entries whose link has the given
